# DynamiKontrol

**Under construction!**

Python API for controlling motors and hardware modules.

Developed and designed by [The Matrix](https://www.m47rix.com) (c) 2021

matrix.ai.solution@gmail.com
